<?xml version="1.0" encoding="UTF-8"?>

<!-- 
	******************************************************************
	**  Voice Toolkit for WebSphere Studio
	**  (C) COPYRIGHT International Business Machines Corp. 2003, 2005
	**  All Rights Reserved * Licensed Materials - Property of IBM
	******************************************************************
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:xalan="http://xml.apache.org/xslt" xmlns="http://www.w3.org/2001/vxml" xmlns:rdc="http://jakarta.apache.org/taglibs/rdc-1.0">

	<!-- Set Parameters -->

	<xsl:param name="lang5" />
	<xsl:param name="vxmlVersion" />
	<xsl:param name="goBackGrammar" />
	<xsl:param name="isJSV" />
	<xsl:param name="hasRDCs" />
	<xsl:param name="previousPromptString" />
	<xsl:param name="JSVContentTypeString" />
	<xsl:param name="globalGrammarLabel" />
	<xsl:param name="beginCallFlowLabel" />
	<xsl:param name="endCallFlowLabel" />
	<xsl:param name="groupComment" />
	<xsl:param name="groupFileName" />
	<xsl:param name="RDCCoreSubmit" />



	<!-- Set Output Method -->

	<xsl:output method="xml" version="1.0" />





	<!-- Match Templates -->

	<!-- Start processing from the root of the document -->
	<xsl:template match="/">
		<xsl:apply-templates />
	</xsl:template>

	<xsl:template match="comment()" name="comment">
		<xsl:copy-of select="current()" />
	</xsl:template>


	<!-- Template Begin(root): Creates the root <vxml> element. -->
	<xsl:template match="root" name="rootElement">
		<!-- Add JSV tag if it is a JSV. -->
		<xsl:if test="$isJSV = 'true'">
			<xsl:text>&#10;</xsl:text>
			<xsl:value-of disable-output-escaping="yes" select="$JSVContentTypeString" />
			<xsl:text>&#10;</xsl:text>
		</xsl:if>
		<xsl:if test="(//rdc:group/@submit = '') or (//rdc:group/@submit = '${self}')">
			<xsl:text>&#10;</xsl:text>
			<xsl:value-of disable-output-escaping="yes" select="$RDCCoreSubmit" />
			<xsl:text>&#10;</xsl:text>
		</xsl:if>
		<xsl:text>&#10;</xsl:text>
		<xsl:element name="vxml">
			<xsl:attribute name="version">
				<xsl:value-of select="$vxmlVersion" />
			</xsl:attribute>
			<xsl:choose>
				<xsl:when test="current()/@lang">
					<xsl:attribute name="xml:lang">
						<xsl:value-of select="translate(current()/@lang, '_', '-')" />
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="xml:lang">
						<xsl:value-of select="$lang5" />
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text>&#10;&#10;</xsl:text>
			<xsl:comment>
				<xsl:value-of select="$beginCallFlowLabel" />
			</xsl:comment>
			<xsl:text>&#10;</xsl:text>
			<!-- Process all comments. -->
			<xsl:for-each select="/root/comment">
				<xsl:call-template name="commentElement" />
			</xsl:for-each>
			<!-- Process the startElement. -->
			<xsl:call-template name="startElement" />
			<!-- Process all global grammars. -->
			<xsl:if test="/root/globalgrammar">
				<xsl:comment>
					<xsl:value-of select="$globalGrammarLabel" />
				</xsl:comment>
				<xsl:text>&#10;</xsl:text>
				<xsl:for-each select="/root/globalgrammar">
					<xsl:call-template name="globalGrammarElement" />
				</xsl:for-each>
			</xsl:if>
			<!-- Process child elements. -->
			<xsl:apply-templates />
			<xsl:text>&#10;</xsl:text>
			<xsl:comment>
				<xsl:value-of select="$endCallFlowLabel" />
			</xsl:comment>
			<xsl:text>&#10;</xsl:text>
		</xsl:element>
	</xsl:template>
	<!-- Template End(root) -->


	<!-- Template Begin(start): Creates the properties and variables. -->
	<xsl:template name="startElement">
		<!-- Add properties. -->
		<xsl:element name="property">
			<xsl:attribute name="name">universals</xsl:attribute>
			<xsl:attribute name="value">help cancel</xsl:attribute>
		</xsl:element>
		<xsl:element name="property">
			<xsl:attribute name="name">audiomaxage</xsl:attribute>
			<xsl:attribute name="value">1</xsl:attribute>
		</xsl:element>
		<xsl:text>&#10;&#10;</xsl:text>
		<!-- Add Global variable for speech/dtmf flow determination. -->
		<xsl:element name="var">
			<xsl:attribute name="name">mode</xsl:attribute>
			<xsl:attribute name="expr">'speech'</xsl:attribute>
		</xsl:element>
		<xsl:element name="var">
			<xsl:attribute name="name">previousResult</xsl:attribute>
		</xsl:element>
		<xsl:text>&#10;&#10;</xsl:text>
	</xsl:template>
	<!-- Template End(start) -->


	<!-- Template Begin(prompt): Creates forms that contain prompts. -->
	<xsl:template match="prompt" name="promptElement">
		<!-- Setup some variables to use later. -->
		<xsl:variable name="precedingRDCId">
			<xsl:call-template name="getPrecedingRDC" />
		</xsl:variable>
		<xsl:variable name="followingRDCId">
			<xsl:call-template name="getFollowingRDC" />
		</xsl:variable>
		<xsl:variable name="formId">
			<xsl:call-template name="getFormId" />
		</xsl:variable>
		<xsl:variable name="builtinType">
			<xsl:choose>
				<xsl:when test="current()/builtin/@value">
					<xsl:value-of select="current()/builtin/@value" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>other</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="fieldId">
			<xsl:value-of select="concat('f', $formId)" />
		</xsl:variable>
		<xsl:variable name="varId">
			<xsl:choose>
				<xsl:when test="current()/@alias">
					<xsl:value-of select="translate(current()/@alias, ' ', '')" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$formId" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="responseCount">
			<xsl:value-of select="count(response)" />
		</xsl:variable>
		<xsl:variable name="defaultGoto">
			<xsl:value-of select="count(link)" />
		</xsl:variable>
		<xsl:variable name="multipleGoto">
			<xsl:value-of select="count(//link)" />
		</xsl:variable>
		<xsl:variable name="responseGotoCount">
			<xsl:value-of select="count(response/link)" />
		</xsl:variable>
		<xsl:variable name="bargeIn">
			<xsl:value-of select="current()/@bargein" />
		</xsl:variable>
		<xsl:variable name="defaultGotoId">
			<xsl:choose>
				<xsl:when test="link/@next">
					<xsl:value-of select="concat('#', link/@next)" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="number('0')" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Create a comment if there is a description. -->
		<xsl:if test="string-length(current()/@description) > 0">
			<xsl:comment>
				<xsl:value-of select="current()/@description"/>
			</xsl:comment>
		</xsl:if>
		<!-- Output a global variable for use with the result of this prompt. -->
		<xsl:element name="var">
			<xsl:attribute name="name">
				<xsl:value-of select="$varId" />
			</xsl:attribute>
		</xsl:element>
		<xsl:if test="current()/@score">
			<xsl:if test="(current()/@score &gt;= 0) and (current()/@score &lt;= 100)">
				<xsl:element name="var">
					<xsl:attribute name="name">
						<xsl:value-of select="concat($varId, '_confidence')" />
					</xsl:attribute>
				</xsl:element>
			</xsl:if>
		</xsl:if>
		<!-- Create the form element and process all child elements. -->
		<xsl:element name="form">
			<xsl:attribute name="id">
				<xsl:value-of select="$formId" />
			</xsl:attribute>
			<xsl:if test="current()/@alias">
				<xsl:comment>
					<xsl:value-of select="current()/@alias" />
				</xsl:comment>
			</xsl:if>
			<!-- Create a goBack grammar if there is a goBack target. -->
			<xsl:if test="current()/@back">
				<xsl:call-template name="goBackGlobalGrammar" />
			</xsl:if>
			<xsl:if test="$hasRDCs = 'true'">
				<xsl:text disable-output-escaping="yes">&#10;&lt;c:if test="${</xsl:text>
				<xsl:value-of select="$followingRDCId" />
				<xsl:text disable-output-escaping="yes">}"&gt;</xsl:text>
				<xsl:text>&#10;</xsl:text>
			</xsl:if>
			<!-- Create the field element. -->
			<xsl:element name="field">
				<xsl:attribute name="name">
					<xsl:choose>
						<xsl:when test="$hasRDCs = 'true'">
							<xsl:value-of select="$formId" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$fieldId" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				<xsl:if test="builtin">
					<xsl:attribute name="type">
						<xsl:value-of select="current()/builtin/@value" />
					</xsl:attribute>
				</xsl:if>
				<!-- Call the appropriate template if it applies. -->
				<xsl:for-each select="grammar">
					<xsl:call-template name="grammarElement" />
				</xsl:for-each>
				<xsl:for-each select="response">
					<xsl:call-template name="responseElement" />
				</xsl:for-each>
				<xsl:text>&#10;&#10;</xsl:text>
				<xsl:for-each select="sprompts">
					<xsl:element name="prompt">
						<xsl:attribute name="cond">mode == 'speech'</xsl:attribute>
						<xsl:attribute name="bargein">
							<xsl:value-of select="$bargeIn" />
						</xsl:attribute>
						<xsl:apply-templates />
					</xsl:element>
				</xsl:for-each>
				<xsl:for-each select="dprompts">
					<xsl:element name="prompt">
						<xsl:attribute name="cond">mode == 'dtmf'</xsl:attribute>
						<xsl:attribute name="bargein">
							<xsl:value-of select="$bargeIn" />
						</xsl:attribute>
						<xsl:apply-templates />
					</xsl:element>
				</xsl:for-each>
				<!-- Create the filled element. -->
				<xsl:element name="filled">
					<!-- Check if there is a valid score value and process if it is. -->
					<xsl:if test="current()/@score">
						<xsl:if test="(current()/@score &gt;= 0) and (current()/@score &lt;= 100)">
							<xsl:call-template name="confidenceCode">
								<xsl:with-param name="confidenceScore">
									<xsl:value-of select="current()/@score" />
								</xsl:with-param>
								<xsl:with-param name="fieldId">
									<xsl:value-of select="$fieldId" />
								</xsl:with-param>
							</xsl:call-template>
							<xsl:text>&#10;&#10;</xsl:text>
							<xsl:element name="assign">
								<xsl:attribute name="name">
									<xsl:value-of select="concat($varId, '_confidence')" />
								</xsl:attribute>
								<xsl:attribute name="expr">
									<xsl:value-of select="concat($fieldId, '$.confidence')" />
								</xsl:attribute>
							</xsl:element>
						</xsl:if>
					</xsl:if>
					<!-- Assign the global variable with the filled value. -->
					<xsl:element name="assign">
						<xsl:attribute name="name">
							<xsl:value-of select="$varId" />
						</xsl:attribute>
						<xsl:attribute name="expr">
							<xsl:value-of select="$fieldId" />
						</xsl:attribute>
					</xsl:element>
					<xsl:element name="assign">
						<xsl:attribute name="name">previousResult</xsl:attribute>
						<xsl:attribute name="expr">
							<xsl:value-of select="$fieldId" />
						</xsl:attribute>
					</xsl:element>
					<xsl:text>&#10;&#10;</xsl:text>
					<!-- Process all response elements. -->
					<xsl:if test="$responseGotoCount > 0">
						<xsl:for-each select="response[link]">
							<xsl:choose>
								<xsl:when test="position() = 1">
									<xsl:if test="$multipleGoto > 0 or $responseGotoCount > 0">
										<xsl:text disable-output-escaping="yes">&#60;if cond=&quot;</xsl:text>
										<xsl:value-of select="$fieldId" />
										<xsl:text>&#32;==&#32;</xsl:text>
										<xsl:choose>
											<xsl:when test="$builtinType = 'boolean'">
												<xsl:value-of select="current()/@value" />
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>'</xsl:text>
												<xsl:value-of select="current()/@value" />
												<xsl:text>'</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:text disable-output-escaping="yes">&quot;&#62;</xsl:text>
										<!-- Check if there is a valid score value and process if it is. -->
										<xsl:if test="score">
											<xsl:if test="(score/@value &gt;= 0) and (score/@value &lt;= 100)">
												<xsl:call-template name="confidenceCode">
													<xsl:with-param name="confidenceScore">
														<xsl:value-of select="score/@value" />
													</xsl:with-param>
													<xsl:with-param name="fieldId">
														<xsl:value-of select="$fieldId" />
													</xsl:with-param>
												</xsl:call-template>
											</xsl:if>
										</xsl:if>
										<!-- Process the link if it exists for the response element. -->
										<xsl:choose>
											<xsl:when test="link">
												<xsl:for-each select="link">
													<xsl:call-template name="linkElement" />
												</xsl:for-each>
											</xsl:when>
											<xsl:otherwise>
												<xsl:if test="$defaultGotoId != 0">
													<xsl:element name="goto">
														<xsl:attribute name="next">
															<xsl:value-of select="$defaultGotoId" />
														</xsl:attribute>
													</xsl:element>
												</xsl:if>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:if>
								</xsl:when>
								<xsl:otherwise>
									<xsl:element name="elseif">
										<xsl:attribute name="cond">
											<xsl:value-of select="$fieldId" />
											<xsl:text>&#32;==&#32;</xsl:text>
											<xsl:choose>
												<xsl:when test="$builtinType = 'boolean'">
													<xsl:value-of select="current()/@value" />
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>'</xsl:text>
													<xsl:value-of select="current()/@value" />
													<xsl:text>'</xsl:text>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:attribute>
									</xsl:element>
									<!-- Check if there is a valid score value and process if it is. -->
									<xsl:if test="score">
										<xsl:if test="(score/@value &gt;= 0) and (score/@value &lt;= 100)">
											<xsl:call-template name="confidenceCode">
												<xsl:with-param name="confidenceScore">
													<xsl:value-of select="score/@value" />
												</xsl:with-param>
												<xsl:with-param name="fieldId">
													<xsl:value-of select="$fieldId" />
												</xsl:with-param>
											</xsl:call-template>
										</xsl:if>
									</xsl:if>
									<xsl:choose>
										<xsl:when test="link">
											<xsl:for-each select="link">
												<xsl:call-template name="linkElement" />
											</xsl:for-each>
										</xsl:when>
										<xsl:otherwise>
											<xsl:if test="$defaultGotoId != 0">
												<xsl:element name="goto">
													<xsl:attribute name="next">
														<xsl:value-of select="$defaultGotoId" />
													</xsl:attribute>
												</xsl:element>
											</xsl:if>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:if>
					<!-- Create an <else> element if necessary. -->
					<xsl:if test="$responseGotoCount > 0 and $defaultGoto > 0">
						<xsl:element name="else" />
					</xsl:if>
					<xsl:for-each select="link">
						<xsl:call-template name="linkElement" />
					</xsl:for-each>
					<!-- Finish the link tags (goto) with a closing </if>. -->
					<xsl:if test="$responseGotoCount > 0">
						<xsl:text disable-output-escaping="yes">&#60;/if&#62;</xsl:text>
					</xsl:if>
				</xsl:element>
			</xsl:element>
			<xsl:if test="$hasRDCs = 'true'">
				<xsl:text>&#10;</xsl:text>
				<xsl:text disable-output-escaping="yes">&lt;/c:if&gt;&#10;</xsl:text>
			</xsl:if>
			<!-- Process <catch> elements if necessary. -->
			<xsl:if test="catch">
				<xsl:variable name="helpCount">
					<xsl:value-of select="count(//event[@name = 'help'])" />
				</xsl:variable>
				<xsl:variable name="noinputCount">
					<xsl:value-of select="count(//event[@name = 'noinput'])" />
				</xsl:variable>
				<xsl:variable name="nomatchCount">
					<xsl:value-of select="count(//event[@name = 'nomatch'])" />
				</xsl:variable>
				<xsl:variable name="gotoCount">
					<xsl:value-of select="count(//event[@name = 'goto'])" />
				</xsl:variable>
				<xsl:for-each select="catch">
					<xsl:for-each select="event[@name = 'help']">
						<xsl:call-template name="catchElement" />
						<xsl:if test="(position() = $helpCount) and ($gotoCount > 0)">
							<xsl:call-template name="catchGotoElement">
								<xsl:with-param name="eventName">
									<xsl:value-of select="current()/@name" />
								</xsl:with-param>
							</xsl:call-template>
						</xsl:if>
					</xsl:for-each>
					<xsl:for-each select="event[@name = 'noinput']">
						<xsl:call-template name="catchElement" />
						<xsl:if test="(position() = $noinputCount) and ($gotoCount > 0)">
							<xsl:call-template name="catchGotoElement">
								<xsl:with-param name="eventName">
									<xsl:value-of select="current()/@name" />
								</xsl:with-param>
							</xsl:call-template>
						</xsl:if>
					</xsl:for-each>
					<xsl:for-each select="event[@name = 'nomatch']">
						<xsl:call-template name="catchElement" />
						<xsl:if test="(position() = $nomatchCount) and ($gotoCount > 0)">
							<xsl:call-template name="catchGotoElement">
								<xsl:with-param name="eventName">
									<xsl:value-of select="current()/@name" />
								</xsl:with-param>
							</xsl:call-template>
						</xsl:if>
					</xsl:for-each>
				</xsl:for-each>
			</xsl:if>
		</xsl:element>
		<xsl:text>&#10;&#10;</xsl:text>
	</xsl:template>
	<!-- Template End(prompt) -->


	<!-- Template Begin(statement): Creates forms that contain statements. -->
	<xsl:template match="statement" name="statementElement">
		<xsl:variable name="precedingRDCId">
			<xsl:call-template name="getPrecedingRDC" />
		</xsl:variable>
		<xsl:variable name="followingRDCId">
			<xsl:call-template name="getFollowingRDC" />
		</xsl:variable>
		<xsl:variable name="formId">
			<xsl:call-template name="getFormId" />
		</xsl:variable>
		<!-- Create a comment if there is a description. -->
		<xsl:if test="string-length(current()/@description) > 0">
			<xsl:comment>
				<xsl:value-of select="current()/@description"/>
			</xsl:comment>
		</xsl:if>
		<!-- Create the form element. -->
		<xsl:element name="form">
			<xsl:attribute name="id">
				<xsl:value-of select="$formId" />
			</xsl:attribute>
			<xsl:if test="current()/@alias">
				<xsl:text>&#10;</xsl:text>
				<xsl:comment>
					<xsl:value-of select="current()/@alias" />
				</xsl:comment>
				<xsl:text>&#10;</xsl:text>
			</xsl:if>
			<!-- Create a goBack grammar if there is a goBack target. -->
			<xsl:if test="current()/@back">
				<xsl:call-template name="goBackGlobalGrammar" />
			</xsl:if>
			<!-- Create an RDC tag if there are any children tags starting with 'rdc:'. -->
			<xsl:if test="$hasRDCs = 'true'">
				<xsl:choose>
					<xsl:when test="current()/@isRDC = 'true'">
						<xsl:choose>
							<xsl:when test="preceding-sibling::*[@isRDC = 'true'][1]">
								<xsl:text disable-output-escaping="yes">&#10;&lt;c:if test="${!(empty&#32;</xsl:text>
								<xsl:value-of select="$precedingRDCId" />
								<xsl:text disable-output-escaping="yes">)}"&gt;</xsl:text>
								<xsl:call-template name="rdcTagCreation" />
								<xsl:text disable-output-escaping="yes">&lt;/c:if&gt;&#10;</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="rdcTagCreation" />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text disable-output-escaping="yes">&#10;&lt;c:if test="${</xsl:text>
						<xsl:value-of select="$followingRDCId" />
						<xsl:text disable-output-escaping="yes">}"&gt;</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<!-- Create the block for the statement and process the children. -->
			<xsl:text>&#10;</xsl:text>
			<xsl:if test="(not(current()/@isRDC)) or (current()/@isRDC = 'false')">
				<xsl:element name="block">
					<xsl:if test="$hasRDCs = 'true'">
						<xsl:attribute name="name">
							<xsl:value-of select="$formId" />
						</xsl:attribute>
					</xsl:if>
					<xsl:for-each select="comment">
						<xsl:call-template name="commentElement" />
					</xsl:for-each>
					<xsl:for-each select="sprompts">
						<xsl:element name="prompt">
							<xsl:apply-templates />
						</xsl:element>
					</xsl:for-each>
					<xsl:for-each select="link">
						<xsl:call-template name="linkElement" />
					</xsl:for-each>
					<xsl:for-each select="notes">
						<xsl:call-template name="notesElement" />
					</xsl:for-each>
					<xsl:for-each select="processing">
						<xsl:call-template name="processingElement" />
					</xsl:for-each>
				</xsl:element>
			</xsl:if>
			<xsl:text>&#10;</xsl:text>
			<xsl:for-each select="phone">
				<xsl:call-template name="phoneElement" />
			</xsl:for-each>
		</xsl:element>
		<xsl:if test="$hasRDCs = 'true'">
			<xsl:choose>
				<xsl:when test="current()/@isRDC = 'true'"></xsl:when>
				<xsl:otherwise>
					<xsl:text>&#10;</xsl:text>
					<xsl:text disable-output-escaping="yes">&lt;/c:if&gt;&#10;</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:text>&#10;&#10;</xsl:text>
	</xsl:template>
	<!-- Template End(statement) -->


	<!-- Template Begin(statement): Creates forms that contains user modified code. -->
	<xsl:template match="statement[//code]">
		<xsl:copy-of select="current()/code/child::*" />
	</xsl:template>
	<!-- Template End(statement): ...of user modified code. -->


	<!-- Template Begin(decision): Creates forms that contains a conditional decision. -->
	<xsl:template match="decision" name="decisionElement">
		<xsl:variable name="precedingRDCId">
			<xsl:call-template name="getPrecedingRDC" />
		</xsl:variable>
		<xsl:variable name="followingRDCId">
			<xsl:call-template name="getFollowingRDC" />
		</xsl:variable>
		<xsl:variable name="formId">
			<xsl:call-template name="getFormId" />
		</xsl:variable>
		<!-- Create a comment if there is a description. -->
		<xsl:if test="string-length(current()/@description) > 0">
			<xsl:comment>
				<xsl:value-of select="current()/@description"/>
			</xsl:comment>
		</xsl:if>
		<!-- Create the form element. -->
		<xsl:element name="form">
			<xsl:attribute name="id">
				<xsl:value-of select="$formId" />
			</xsl:attribute>
			<xsl:if test="current()/@alias">
				<xsl:comment>
					<xsl:value-of select="current()/@alias" />
				</xsl:comment>
			</xsl:if>
			<!-- Create a goBack grammar if there is a goBack target. -->
			<xsl:if test="current()/@back">
				<xsl:call-template name="goBackGlobalGrammar" />
			</xsl:if>
			<xsl:if test="$hasRDCs = 'true'">
				<xsl:text disable-output-escaping="yes">&#10;&lt;c:if test="${</xsl:text>
				<xsl:value-of select="$followingRDCId" />
				<xsl:text disable-output-escaping="yes">}"&gt;</xsl:text>
			</xsl:if>
			<!-- Create the block for the decision and process the children. -->
			<xsl:text>&#10;</xsl:text>
			<xsl:element name="block">
				<xsl:if test="$hasRDCs = 'true'">
					<xsl:attribute name="name">
						<xsl:value-of select="$formId" />
					</xsl:attribute>
				</xsl:if>
				<xsl:if test="condition">
					<xsl:choose>
						<xsl:when test="string-length(condition/@rightvalue) > 0">
							<xsl:variable name="leftSideCondition">
								<xsl:text>(</xsl:text>
								<xsl:value-of select="condition/@leftvalue" />
								<xsl:text>&#32;</xsl:text>
								<xsl:value-of select="condition/@condition" />
								<xsl:text>&#32;</xsl:text>
								<xsl:value-of select="condition/@rightvalue" />
								<xsl:text>)</xsl:text>
							</xsl:variable>
							<xsl:for-each select="response">
								<xsl:element name="if">
									<xsl:attribute name="cond">
										<xsl:value-of select="$leftSideCondition" />
										<xsl:text>&#32;==&#32;</xsl:text>
										<xsl:value-of select="current()/@value" />
									</xsl:attribute>
									<xsl:for-each select="link">
										<xsl:call-template name="linkElement" />
									</xsl:for-each>
								</xsl:element>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="leftSideCondition">
								<xsl:value-of select="condition/@leftvalue" />
							</xsl:variable>
							<xsl:variable name="condition">
								<xsl:value-of select="condition/@condition" />
							</xsl:variable>
							<xsl:for-each select="response">
								<xsl:element name="if">
									<xsl:attribute name="cond">
										<xsl:value-of select="$leftSideCondition" />
										<xsl:text>&#32;</xsl:text>
										<xsl:value-of select="$condition" />
										<xsl:text>&#32;</xsl:text>
										<xsl:value-of select="current()/@value" />
									</xsl:attribute>
									<xsl:for-each select="link">
										<xsl:call-template name="linkElement" />
									</xsl:for-each>
								</xsl:element>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<xsl:for-each select="link">
					<xsl:call-template name="linkElement" />
				</xsl:for-each>
			</xsl:element>
			<xsl:if test="$hasRDCs = 'true'">
				<xsl:text>&#10;</xsl:text>
				<xsl:text disable-output-escaping="yes">&lt;/c:if&gt;&#10;</xsl:text>
			</xsl:if>
		</xsl:element>
		<xsl:text>&#10;&#10;</xsl:text>
	</xsl:template>
	<!-- Template End(decision) -->


	<xsl:template match="sprompt | dprompt">
		<xsl:choose>
			<xsl:when test="(current()[@markup = 'break']) | (current()[@markup = 'tts'])">
				<xsl:if test="current()/@markup = 'break'">
					<xsl:element name="break">
						<xsl:attribute name="time">
							<xsl:choose>
								<xsl:when test="contains(current()/@value, 's')">
									<xsl:value-of select="current()/@value" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="concat(current()/@value, 'ms')" />
								</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="current()/@markup = 'tts'">
					<xsl:choose>
						<xsl:when test="string-length(current()/@src) > 0">
							<xsl:element name="audio">
								<xsl:attribute name="src">
									<xsl:value-of select="current()/@src" />
								</xsl:attribute>
								<xsl:if test="current()/@value">
									<xsl:call-template name="valueCheck">
										<xsl:with-param name="ttsString">
											<xsl:value-of select="current()/@value" />
										</xsl:with-param>
									</xsl:call-template>
								</xsl:if>
							</xsl:element>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="valueCheck">
								<xsl:with-param name="ttsString">
									<xsl:value-of select="current()/@value" />
								</xsl:with-param>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="say-as">
					<xsl:attribute name="interpret-as">
						<xsl:value-of select="concat('vxml:', current()/@markup)" />
					</xsl:attribute>
					<xsl:if test="current()/@value">
						<xsl:call-template name="valueCheck">
							<xsl:with-param name="ttsString">
								<xsl:value-of select="current()/@value" />
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>



	<!-- Self contained commonly used code invoked by name. -->

	<xsl:template name="getFormId">
		<xsl:choose>
			<xsl:when test="current()/@id">
				<xsl:value-of select="current()/@id" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>fERROR</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- Construct the goto element. -->
	<xsl:template name="linkElement">
		<xsl:choose>
			<xsl:when test="(current()/@goto = 'true') and ($hasRDCs = 'true')">
				<xsl:if test="not(current()/@next = //statement[@isRDC = 'true']/@id)">
					<xsl:element name="goto">
						<xsl:choose>
							<xsl:when test="(current()/@next) and (string-length(current()/@next) &gt; 0)">
								<xsl:attribute name="nextitem">
									<xsl:value-of select="current()/@next" />
								</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="nextitem">
									<xsl:text>undefined</xsl:text>
								</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="current()/@goto = 'true'">
					<xsl:element name="goto">
						<xsl:choose>
							<xsl:when test="(current()/@next) and (string-length(current()/@next) &gt; 0)">
								<xsl:attribute name="next">
									<xsl:value-of select="concat('#', current()/@next)" />
								</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="next">
									<xsl:text>undefined</xsl:text>
								</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- Construct the TTS and audio source for the element. -->
	<xsl:template name="speechElement">
		<xsl:choose>
			<xsl:when test="current()/@audio">
				<xsl:element name="audio">
					<xsl:choose>
						<xsl:when test="current()/@audio">
							<xsl:attribute name="src">
								<xsl:value-of select="current()/@audio" />
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="src">
								<xsl:text>undefined</xsl:text>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="current()/@tts">
						<xsl:call-template name="valueCheck">
							<xsl:with-param name="ttsString">
								<xsl:value-of select="current()/@tts" />
							</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="current()/@tts">
					<xsl:call-template name="valueCheck">
						<xsl:with-param name="ttsString">
							<xsl:value-of select="current()/@tts" />
						</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- Check the inputString for '<' and '>' and default to a <value/> tag. -->
	<xsl:template name="valueCheck">
		<xsl:param name="ttsString" />
		<xsl:variable name="valueBegin" select="'&lt;&quot;'" />
		<xsl:variable name="valueEnd" select="'&quot;&gt;'" />
		<xsl:variable name="finalValueBegin" select="'^value expr=&quot;'" />
		<xsl:variable name="finalValueEnd" select="'&quot;/~'" />
		<xsl:if test="contains($ttsString, $valueBegin) and contains($ttsString, $valueEnd)">
			<xsl:variable name="tempStringBegin" select="concat(substring-before($ttsString, $valueBegin), $finalValueBegin, substring-after($ttsString, $valueBegin))" />
			<xsl:variable name="tempStringEnd" select="concat(substring-before($tempStringBegin, $valueEnd), $finalValueEnd, substring-after($tempStringBegin, $valueEnd))" />
			<xsl:if test="contains($tempStringEnd, $valueBegin) and contains($tempStringEnd, $valueEnd)">
				<xsl:call-template name="valueCheck">
					<xsl:with-param name="ttsString">
						<xsl:value-of select="$tempStringEnd" />
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="not(contains($tempStringEnd, $valueBegin) and contains($tempStringEnd, $valueEnd))">
				<xsl:call-template name="previousPromptResultCheck">
					<xsl:with-param name="ttsString">
						<xsl:value-of select="translate($tempStringEnd, '^~', '&lt;&gt;')" />
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:if test="not(contains($ttsString, $valueBegin) and contains($ttsString, $valueEnd))">
			<xsl:call-template name="previousPromptResultCheck">
				<xsl:with-param name="ttsString">
					<xsl:value-of select="translate($ttsString, '^~', '&lt;&gt;')" />
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>


	<!-- Check the inputString for 'Previous Prompt Result' and change to 'previousResult'. -->
	<xsl:template name="previousPromptResultCheck">
		<xsl:param name="ttsString" />
		<xsl:variable name="lastResult" select="'&quot;previousResult&quot;'" />
		<xsl:if test="contains($ttsString, $previousPromptString)">
			<xsl:variable name="tempString" select="concat(substring-before($ttsString, $previousPromptString), string($lastResult), substring-after($ttsString, $previousPromptString))" />
			<xsl:if test="contains($tempString, $previousPromptString)">
				<xsl:call-template name="previousPromptResultCheck">
					<xsl:with-param name="ttsString">
						<xsl:value-of select="$tempString" />
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="not(contains($tempString, $previousPromptString))">
				<xsl:call-template name="outputTTSText">
					<xsl:with-param name="ttsString">
						<xsl:value-of select="$tempString" />
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:if test="not(contains($ttsString, $previousPromptString))">
			<xsl:call-template name="outputTTSText">
				<xsl:with-param name="ttsString">
					<xsl:value-of select="$ttsString" />
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>


	<!-- Check the inputString for <value/> tags and output the TTS either escaped or not. -->
	<xsl:template name="outputTTSText">
		<xsl:param name="ttsString" />
		<xsl:variable name="finalValueBegin" select="'&lt;value expr=&quot;'" />
		<xsl:variable name="finalValueEnd" select="'&quot;/&gt;'" />
		<xsl:if test="contains($ttsString, $finalValueBegin) and contains($ttsString, $finalValueEnd)">
			<xsl:variable name="tempString" select="substring-before($ttsString, $finalValueEnd)" />
			<xsl:variable name="beginString" select="substring-before($tempString, $finalValueBegin)" />
			<xsl:variable name="valueString" select="concat($finalValueBegin, substring-after($tempString, $finalValueBegin), $finalValueEnd)" />
			<xsl:variable name="endString" select="substring-after($ttsString, $finalValueEnd)" />
			<xsl:value-of select="$beginString" />
			<xsl:value-of select="$valueString" disable-output-escaping="yes" />
			<xsl:if test="contains($endString, $finalValueBegin) and contains($endString, $finalValueEnd)">
				<xsl:call-template name="outputTTSText">
					<xsl:with-param name="ttsString">
						<xsl:value-of select="$endString" />
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="not(contains($endString, $finalValueBegin) and contains($endString, $finalValueEnd))">
				<xsl:value-of select="$endString" />
			</xsl:if>
		</xsl:if>
		<xsl:if test="not(contains($ttsString, $finalValueBegin) and contains($ttsString, $finalValueEnd))">
			<xsl:value-of select="$ttsString" />
		</xsl:if>
	</xsl:template>


	<!-- Construct user defined responses (options) for the element. -->
	<xsl:template name="responseElement">
		<xsl:variable name="optionValue">
			<xsl:value-of select="current()/@value" />
		</xsl:variable>
		<xsl:element name="option">
			<xsl:attribute name="value">
				<xsl:value-of select="$optionValue" />
			</xsl:attribute>
			<xsl:if test="dtmf">
				<xsl:attribute name="dtmf">
					<xsl:value-of select="dtmf/@value" />
				</xsl:attribute>
			</xsl:if>
			<xsl:value-of select="$optionValue" />
		</xsl:element>
		<xsl:for-each select="alternate">
			<xsl:element name="option">
				<xsl:attribute name="value">
					<xsl:value-of select="$optionValue" />
				</xsl:attribute>
				<xsl:value-of select="current()/@value" />
			</xsl:element>
		</xsl:for-each>
	</xsl:template>


	<!-- Construct a catch event with a reprompt. -->
	<xsl:template name="catchElement">
		<xsl:text>&#10;&#10;</xsl:text>
		<xsl:element name="{current()/@name}">
			<xsl:attribute name="count">
				<xsl:value-of select="current()/@count" />
			</xsl:attribute>
			<xsl:for-each select="speech">
				<xsl:call-template name="speechElement" />
			</xsl:for-each>
			<xsl:element name="reprompt" />
		</xsl:element>
	</xsl:template>


	<!-- Construct an additional catch for the event with a goto instead of reprompt. -->
	<xsl:template name="catchGotoElement">
		<xsl:param name="eventName" />
		<xsl:text>&#10;&#10;</xsl:text>
		<xsl:element name="{$eventName}">
			<xsl:attribute name="count">
				<xsl:value-of select="number(@count) + 1" />
			</xsl:attribute>
			<xsl:for-each select="../event[@name = 'goto']/link">
				<xsl:call-template name="linkElement" />
			</xsl:for-each>
		</xsl:element>
	</xsl:template>


	<!-- Construct a grammar element for an external grammar. -->
	<xsl:template name="grammarElement">
		<xsl:element name="grammar">
			<xsl:attribute name="src">
				<xsl:value-of select="current()/@value" />
			</xsl:attribute>
			<xsl:attribute name="mode">
				<xsl:text>voice</xsl:text>
			</xsl:attribute>
		</xsl:element>
	</xsl:template>


	<!-- Construct a transfer element. -->
	<xsl:template name="phoneElement">
		<xsl:element name="transfer">
			<xsl:attribute name="bridge">
				<xsl:text>false</xsl:text>
			</xsl:attribute>
			<xsl:attribute name="dest">
				<xsl:text>tel:</xsl:text>
				<xsl:value-of select="current()/@value" />
			</xsl:attribute>
		</xsl:element>
	</xsl:template>


	<!-- Construct a conditional to compare confidence score. -->
	<xsl:template name="confidenceCode">
		<xsl:param name="confidenceScore" />
		<xsl:param name="fieldId" />
		<xsl:element name="if">
			<xsl:attribute name="cond">
				<xsl:value-of select="concat($fieldId, '$.confidence &lt;&#32;', ($confidenceScore div 100))" />
			</xsl:attribute>
			<xsl:element name="throw">
				<xsl:attribute name="event">
					<xsl:text>nomatch</xsl:text>
				</xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>


	<!-- Grammar to use when targetGoBackId is filled. -->
	<xsl:template name="commentElement">
		<xsl:text>&#10;</xsl:text>
		<xsl:comment>
			<xsl:value-of select="current()/@value" />
		</xsl:comment>
	</xsl:template>


	<!-- Notes in the form of a comment. -->
	<xsl:template name="notesElement">
		<xsl:text>&#10;</xsl:text>
		<xsl:comment>
			<xsl:value-of select="current()/@value" />
		</xsl:comment>
	</xsl:template>


	<!-- Processing instructions in the form of a comment. -->
	<xsl:template name="processingElement">
		<xsl:text>&#10;</xsl:text>
		<xsl:comment>
			<xsl:value-of select="current()/@value" />
		</xsl:comment>
	</xsl:template>


	<!-- Construct Global Grammars. -->
	<xsl:template name="globalGrammarElement">
		<xsl:for-each select="response">
			<xsl:if test="(string-length(current()/@value) > 0) and (string-length(link/@next) > 0)">
				<xsl:element name="link">
					<xsl:attribute name="next">
						<xsl:for-each select="link">
							<xsl:value-of select="concat('#', current()/@next)" />
						</xsl:for-each>
					</xsl:attribute>
					<xsl:element name="grammar">
						<xsl:attribute name="mode">
							<xsl:text>voice</xsl:text>
						</xsl:attribute>
						<xsl:attribute name="version">
							<xsl:text>1.0</xsl:text>
						</xsl:attribute>
						<xsl:attribute name="root">
							<xsl:value-of select="translate(current()/@value, ' ', '')" />
						</xsl:attribute>
						<xsl:attribute name="xml:lang">
							<xsl:value-of select="$lang5" />
						</xsl:attribute>
						<xsl:element name="rule">
							<xsl:attribute name="id">
								<xsl:value-of select="translate(current()/@value, ' ', '')" />
							</xsl:attribute>
							<xsl:attribute name="scope">
								<xsl:text>public</xsl:text>
							</xsl:attribute>
							<xsl:element name="item">
								<xsl:value-of select="current()/@value" />
							</xsl:element>
							<xsl:for-each select="alternate">
								<xsl:element name="item">
									<xsl:value-of select="current()/@value" />
								</xsl:element>
							</xsl:for-each>
						</xsl:element>
					</xsl:element>
					<xsl:if test="dtmf">
						<xsl:element name="grammar">
							<xsl:attribute name="mode">
								<xsl:text>dtmf</xsl:text>
							</xsl:attribute>
							<xsl:attribute name="version">
								<xsl:text>1.0</xsl:text>
							</xsl:attribute>
							<xsl:attribute name="root">
								<xsl:text>dtmf_</xsl:text>
								<xsl:value-of select="dtmf/@value" />
							</xsl:attribute>
							<xsl:element name="rule">
								<xsl:attribute name="id">
									<xsl:text>dtmf_</xsl:text>
									<xsl:value-of select="dtmf/@value" />
								</xsl:attribute>
								<xsl:attribute name="scope">
									<xsl:text>public</xsl:text>
								</xsl:attribute>
								<xsl:element name="item">
									<xsl:value-of select="dtmf/@value" />
								</xsl:element>
							</xsl:element>
						</xsl:element>
					</xsl:if>
				</xsl:element>
				<xsl:text>&#10;&#10;</xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>


	<!-- Grammar to use when targetGoBackId is filled. -->
	<xsl:template name="goBackGlobalGrammar">
		<xsl:element name="link">
			<xsl:attribute name="next">
				<xsl:value-of select="concat('#', current()/@back)" />
			</xsl:attribute>
			<xsl:element name="grammar">
				<xsl:attribute name="mode">
					<xsl:text>voice</xsl:text>
				</xsl:attribute>
				<xsl:attribute name="version">
					<xsl:text>1.0</xsl:text>
				</xsl:attribute>
				<xsl:attribute name="root">
					<xsl:value-of select="concat(translate($goBackGrammar, ' ', ''), '_', current()/@id)" />
				</xsl:attribute>
				<xsl:attribute name="xml:lang">
					<xsl:value-of select="$lang5" />
				</xsl:attribute>
				<xsl:element name="rule">
					<xsl:attribute name="id">
						<xsl:value-of select="concat(translate($goBackGrammar, ' ', ''), '_', current()/@id)" />
					</xsl:attribute>
					<xsl:attribute name="scope">
						<xsl:text>public</xsl:text>
					</xsl:attribute>
					<xsl:element name="item">
						<xsl:value-of select="$goBackGrammar" />
					</xsl:element>
				</xsl:element>
			</xsl:element>
		</xsl:element>
		<xsl:text>&#10;&#10;</xsl:text>
	</xsl:template>

	<!-- RDC tag generation. -->
	<xsl:template name="rdcTagCreation">
		<xsl:variable name="rdcId">
			<xsl:choose>
				<xsl:when test="current()/@alias">
					<xsl:value-of select="translate(current()/@alias, ' ', '')" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="current()/@id" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:text>&#10;</xsl:text>
		<xsl:for-each select="child::*[starts-with(name(.), 'rdc:')]">
			<xsl:copy>
				<xsl:attribute name="id">
					<xsl:choose>
						<xsl:when test="string-length($groupFileName) > 0">
							<xsl:value-of select="concat($groupFileName, '-', $rdcId)" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$rdcId" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				<xsl:for-each select="current()/@*[(not(name(.)='group')) and (not( . = '')) and (not(name(.)='id'))]">
					<xsl:copy></xsl:copy>
				</xsl:for-each>
				<xsl:if test="name(.) = 'rdc:group'">
					<xsl:if test="current()/@strategy = ''">
						<xsl:attribute name="strategy">org.apache.taglibs.rdc.dm.SimpleDirectedDialog</xsl:attribute>
					</xsl:if>
					<xsl:if test="current()/@submit = ''">
						<xsl:attribute name="submit">${self}</xsl:attribute>
					</xsl:if>
					<xsl:text>&#10;</xsl:text>
					<xsl:value-of select="$groupComment" disable-output-escaping="yes" />
					<xsl:text>&#10;</xsl:text>
				</xsl:if>
			</xsl:copy>
		</xsl:for-each>
		<xsl:text>&#10;</xsl:text>
	</xsl:template>


	<xsl:template name="getPrecedingRDC">
		<xsl:choose>
			<xsl:when test="preceding-sibling::*[@isRDC = 'true'][1]/@alias">
				<xsl:value-of select="translate(preceding-sibling::*[@isRDC = 'true'][1]/@alias, ' ', '')" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="preceding-sibling::*[@isRDC = 'true'][1]/@id" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template name="getFollowingRDC">
		<xsl:choose>
			<xsl:when test="following-sibling::*[@isRDC = 'true'][1]/@alias">
				<xsl:value-of select="concat('empty dialogMap.', translate(following-sibling::*[@isRDC = 'true'][1]/@alias, ' ', ''))" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="following-sibling::*[@isRDC = 'true'][1]/@id">
						<xsl:value-of select="concat('empty dialogMap.', following-sibling::*[@isRDC = 'true'][1]/@id)" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="preceding-sibling::*[@isRDC = 'true'][1]/@alias">
								<xsl:value-of select="concat('!(empty ', translate(preceding-sibling::*[@isRDC = 'true'][1]/@alias, ' ', ''), ')')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat('!(empty ', preceding-sibling::*[@isRDC = 'true'][1]/@id, ')')" />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template name="rdcNameList">
		<xsl:for-each select="//statement[@isRDC = 'true']">
			<xsl:choose>
				<xsl:when test="current()/@alias">
					<xsl:value-of select="translate(current()/@alias, ' ', '')" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="current()/@id" />
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="position() != last()">
				<xsl:text>&#32;</xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
